@@ -1,13 +1,14 @@
 package Regexp::Pattern;
 
 our $DATE = '2018-09-10'; # DATE
-our $VERSION = '0.2.6'; # VERSION
+our $VERSION = '0.2.7'; # VERSION
 
 use strict 'subs', 'vars';
 #use warnings;
 
 sub re {
     my $name = shift;
+    my %args = ref($_[0]) eq 'HASH' ? %{$_[0]} : @_;
 
     my ($mod, $patname) = $name =~ /(.+)::(.+)/
         or die "Invalid pattern name '$name', should be 'MODNAME::PATNAME'";
@@ -21,13 +22,20 @@ sub re {
     exists($var->{$patname})
         or die "No regexp pattern named '$patname' in package '$mod'";
 
+    my $pat;
     if ($var->{$patname}{pat}) {
-        return $var->{$patname}{pat};
+        $pat = $var->{$patname}{pat};
     } elsif ($var->{$patname}{gen}) {
-        return $var->{$patname}{gen}->(ref($_[0]) eq 'HASH' ? %{$_[0]} : @_);
+        $pat = $var->{$patname}{gen}->(%args);
     } else {
         die "Bug in module '$mod': pattern '$patname': no pat/gen declared";
     }
+
+    if ($args{-anchor}) {
+            $pat = qr/\A(?:$pat)\z/;
+    }
+
+    return $pat;
 }
 
 sub import {
@@ -133,7 +141,7 @@ Regexp::Pattern - Convention/framework for modules that contain collection of re
 
 =head1 VERSION
 
-This document describes version 0.2.6 of Regexp::Pattern (from Perl distribution Regexp-Pattern), released on 2018-09-10.
+This document describes version 0.2.7 of Regexp::Pattern (from Perl distribution Regexp-Pattern), released on 2018-09-10.
 
 =head1 SYNOPSIS
 
@@ -443,6 +451,9 @@ I<PATTERN_NAME> is a key to the C<%RE> package global hash in the module. A
 dynamic pattern can accept arguments for its generator, and you can pass it as
 hashref in the second argument of C<re()>.
 
+B<Anchoring.> You can also put C<< -anchor => 1 >> in C<%args>. This will
+conveniently wraps the regex inside C<< qr/\A(?:...)\z/ >>.
+
 Die when pattern by name C<$name> cannot be found (either the module cannot be
 loaded or the pattern with that name is not found in the module).
 
